; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;
;-| Super Attacks | -----------------------------------
[Command]
name = "Cavios"
command = ~D, DF, F, a+b
time = 20

;-| Special Attacks |-----------------------------------------------------------
[Command]
name = "Fire Shot"
command = ~D,DF,F, b
time = 10

[Command]
name = "Fire Shot"
command = ~D,DF,F, ~b
time = 10

[Command]
name = "Fire Shot"
command = ~D,DF,F, a
time = 10

[Command]
name = "Fire Shot"
command = ~D,DF,F, ~a
time = 10

[Command]
name = "Fire Tackle"
command = ~30$B, F, a
time = 10

[Command]
name = "Fire Tackle"
command = ~30$B, F, ~a
time = 10

[Command]
name = "Fire Tackle"
command = ~30$B, F, b
time = 10

[Command]
name = "Fire Tackle"
command = ~30$B, F, ~b
time = 10

[Command]
name = "Fire Ball"
command = F, D, DF, a

[Command]
name = "Fire Ball"
command = F, D, DF, b

[Command]
name = "Fire Ball"
command = F, D, DF, ~a

[Command]
name = "Fire Ball"
command = F, D, DF, ~b

[Command]
name = "Fire Ball"
command = F, D, F, a

[Command]
name = "Fire Ball"
command = F, D, F, b

[Command]
name = "Fire Ball"
command = F, D, F, ~a

[Command]
name = "Fire Ball"
command = F, D, F, ~b

[Command]
name = "Fire Breath"
command = ~F, D, B, a

[Command]
name = "Fire Breath"
command = ~F, D, B, b

Command]
name = "Fire Breath"
command = ~F, D, B, ~a

[Command]
name = "Fire Breath"
command = ~F, D, B, ~b

[Command]
name = "Summon Lion"
command = ~30$B, F, a+b
time = 10

[Command]
name = "Summon Lion"
command = ~30$B, F, ~a+b
time = 10


;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = a+b
time = 1

[Command]
name = "DU"
command = $D, $U
time = 10
;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "slide"
command = /$D,a
time = 1

[Command]
name = "slide"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
[Statedef -1]

[State -1, SL]
type = Changestate
value = 3000
triggerall = command = "Summon Lion"
triggerall = Power >= 1000
trigger1 = ctrl
trigger1 = StateType != A
trigger2 = StateNo = [200,210]
trigger2 = MoveContact


[State -1, FT]
type = Changestate
value = ifelse(statetype = A, 1101,1100)
triggerall = command = "Fire Tackle"
trigger1 = ctrl
trigger2 = Stateno = [200,210]
trigger2 = Movecontact

[State -1, FireBreath]
type = Changestate
value = 1300
triggerall = command = "Fire Breath"
trigger1 = statetype!=A
trigger1 = ctrl
trigger2 = StateNo = [200,210]
trigger2 = MoveContact

[State -1, FB]
type = Changestate
value = 1200
triggerall = command = "Fire Ball"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = Stateno = [200,210]
trigger2 = Movecontact

[State -1, FS]
type = Changestate
value = 1000
triggerall = command = "Fire Shot"
triggerall = NumHelper(1005) = 0 || NumHelper(1007) = 0
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = ctrl
trigger2 = StateNo = [200,210]
trigger2 = MoveContact

[State -1, ALA]
type = ChangeState
value = 400
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl

[State -1, AHA]
type = ChangeState
value = 410
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = Stateno = 400
trigger2 = movecontact

[State -1, Slide]
type = ChangeState
value = 300
triggerall = command = "slide"
trigger1 = statetype = C
trigger1 = ctrl


[State -1, SHA]
type = ChangeState
value = 210
triggerall = command = "b"
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = ctrl
trigger2 = StateNo = 200
trigger2 = MoveContact

[State -1, SLA]
type = ChangeState
value = 200
triggerall = command = "a"
trigger1 = statetype = S
trigger1 = ctrl

[State -1, SJ]
type = ChangeState
value = 500
trigger1 = command = "DU"
trigger1 = statetype != A
trigger1 = ctrl

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl
